@@ -29,7 +29,7 @@ define('MIME_CONTENTS_DISPLAY_TYPE_BOTH', 2);
  * The MIME_Contents:: class contains functions related to handling the output
  * of MIME content.
  *
- * $Horde: framework/MIME/MIME/Contents.php,v 1.129.4.42 2008/04/02 23:30:41 jan Exp $
+ * $Horde: framework/MIME/MIME/Contents.php,v 1.129.4.42.4.1 2008/09/10 10:08:43 jan Exp $
  *
  * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
@@ -984,7 +984,7 @@ class MIME_Contents {
             is_a($viewer, 'MIME_Viewer_default')) {
             $summary[] = htmlspecialchars($description);
         } else {
-            $summary[] = $this->linkViewJS($mime_part, $this->_viewID['view'], $description, sprintf(_("View %s [%s]"), $description, $mime_type), null, $param_array);
+            $summary[] = $this->linkViewJS($mime_part, $this->_viewID['view'], htmlspecialchars($description), sprintf(_("View %s [%s]"), $description, $mime_type), null, $param_array);
         }
 
         /* Size. */
@@ -1052,9 +1052,12 @@ class MIME_Contents {
     /**
      * Generate a link to the view.php page.
      *
+     * Important: the calling code has to make sure that the $text parameter
+     * is properly escaped!
+     *
      * @param MIME_Part &$mime_part  The MIME_Part object to view.
      * @param integer $actionID      The actionID value.
-     * @param string $text           The link text.
+     * @param string $text           The ESCAPED (!) link text.
      * @param array $params          A list of additional parameters.
      *   'class'       -  The CSS class to use.
      *   'jstext'      -  The JS text to use.
@@ -1089,9 +1092,12 @@ class MIME_Contents {
     /**
      * Generate a javascript link to the view.php page.
      *
+     * Important: the calling code has to make sure that the $text parameter
+     * is properly escaped!
+     *
      * @param MIME_Part &$mime_part  The MIME_Part object to view.
      * @param integer $actionID      The ActionID to perform.
-     * @param string $text           The link text.
+     * @param string $text           The ESCAPED (!) link text.
      * @param string $jstext         The Javascript link text.
      * @param string $css            The CSS class to use.
      * @param array $params          A list of any additional parameters that
